@@ -10,7 +10,7 @@ class PrivateKey():
 
 
   def save_to_keyfile(self, keyfile_path):
-    fp = open(os.path.join(keyfile_path, "sec.lwe.key"))
+    fp = open(os.path.join(keyfile_path, "sec.lwe.key"), "w")
     data = json.dumps({
       "sec": self.secret
     })
